@@ -1,11 +1,8 @@
 import hashlib
-from itertools import chain
 
-import aiohttp
 import botocore
 import pytest
-from aiohttp.client import ClientResponse
-from botocore import retryhandler
+from botocore import retryhandler, stub
 from botocore.args import ClientArgsCreator
 from botocore.awsrequest import AWSResponse
 from botocore.client import BaseClient, ClientCreator, Config
@@ -94,10 +91,13 @@ from botocore.tokens import (
 )
 from botocore.utils import (
     ContainerMetadataFetcher,
+    IdentityCache,
     IMDSFetcher,
     IMDSRegionProvider,
     InstanceMetadataFetcher,
     InstanceMetadataRegionFetcher,
+    S3ExpressIdentityCache,
+    S3ExpressIdentityResolver,
     S3RegionRedirector,
     S3RegionRedirectorv2,
 )
@@ -115,16 +115,6 @@ from dill.source import getsource
 # 3) If we need to replace the below hash (not backwards compatible) or add
 #    to the set
 
-# The follow is for our monkeypatches for read_timeout:
-#    github.com/aio-libs/aiobotocore/pull/248
-_AIOHTTP_DIGESTS = {
-    # for using _body
-    ClientResponse: {
-        'e178726065b609c69a1c02e8bb78f22efce90792',
-        '225e8033bfcff8cccbc2e975d7bd0c7993f14366',
-    },
-}
-
 # These are guards to our main patches
 
 # !!! README: HOW TO UPDATE THESE !!!
@@ -147,13 +137,15 @@ _AIOHTTP_DIGESTS = {
 _API_DIGESTS = {
     # args.py
     ClientArgsCreator.get_client_args: {
-        '63f26e3225338f285b98a4fe9bdcd1057a0f61b2'
+        '2dc13a6f32c470bc415a2cfc1f82cf569b1a5196'
     },
     ClientArgsCreator._build_endpoint_resolver: {
-        '9aa226b8d6f09f7270633b8cc35bc82a15386ee4'
+        '0f80192233321ae4a55d95b68f5b8a68f3ad18e6',
     },
     # client.py
-    ClientCreator.create_client: {'ef5bef8f4b2887143165e72554fd85c36af7e822'},
+    ClientCreator.create_client: {
+        'eeb7c4730ac86aec37de53b2be0779490b05f50b',
+    },
     ClientCreator._create_client_class: {
         'fcecaf8d4f2c1ac3c5d0eb50c573233ef86d641d'
     },
@@ -161,7 +153,10 @@ _API_DIGESTS = {
         '483c6c8e035810d1b76110fc1956de76943c2f18'
     },
     ClientCreator._get_client_args: {
-        '86edebe5bc72e89e75c593e8f4bf2a3c358f1d8f'
+        'd5e19b1e62f64a745de842963c2472825a66e854'
+    },
+    ClientCreator._register_s3express_events: {
+        '716c1549989eef6bbd048bf4f134c1b4659e124a',
     },
     ClientCreator._register_s3_events: {
         '5659a5312caeb3ea97d663d837d6d201f08824f2'
@@ -178,28 +173,38 @@ _API_DIGESTS = {
     ClientCreator._register_legacy_retries: {
         '000b2f2a122602e2e741ec2e89308dc2e2b67329'
     },
-    BaseClient._make_api_call: {'eba7540893a631a00ebfc3c287026ee6db993e09'},
+    BaseClient._make_api_call: {
+        '2cb11088d36a89cf9f5c41508bce908acbde24c4',
+    },
     BaseClient._make_request: {'cfd8bbf19ea132134717cdf9c460694ddacdbf58'},
     BaseClient._convert_to_request_dict: {
-        '899c223cacbe17be646a33882ecd65aa02290b9b'
+        '5e0a374926b6ee1a8715963ab551e126506e7fc9'
     },
     BaseClient._emit_api_params: {'abd67874dae8d5cd2788412e4699398cb915a119'},
     BaseClient._resolve_endpoint_ruleset: {
-        'e8e7fe581a2e4ff1a75d1ee923c0ed2c6a0d9c9d'
+        'f09731451ff6ba0645dc82e5c7948dfbf781e025',
+    },
+    BaseClient.get_paginator: {
+        '3531d5988aaaf0fbb3885044ccee1a693ec2608b',
+        '1c38079de68ccd43a5a06e36b1a47ec62233a7c2',
+    },
+    BaseClient.get_waiter: {
+        '44f0473d993d49ac7502984a7ccee3240b088404',
+        '4a4aeabe53af25d3737204187a31f930230864b4',
     },
-    BaseClient.get_paginator: {'3531d5988aaaf0fbb3885044ccee1a693ec2608b'},
-    BaseClient.get_waiter: {'44f0473d993d49ac7502984a7ccee3240b088404'},
     BaseClient.__getattr__: {'3ec17f468f50789fa633d6041f40b66a2f593e77'},
     # config.py
     Config.merge: {'c3dd8c3ffe0da86953ceba4a35267dfb79c6a2c8'},
-    Config: {'c22f76d2e45e575d99ae130cdba8ea31cb7f4cdc'},
+    Config: {
+        '9154efda503c21ab9aa048214ddca7aa637e2ff9',
+    },
     # credentials.py
     create_mfa_serial_refresher: {'9b5e98782fcacdcea5899a6d0d29d1b9de348bb0'},
     Credentials.get_frozen_credentials: {
         'eb247f2884aee311bdabba3435e749c3b8589100'
     },
     RefreshableCredentials.__init__: {
-        '1a6b83fc845f05feab117ce4fab73b13baed6e3b'
+        '25ee814f47e5ce617f57e893ae158e5fd6d358ea',
     },
     # We've overridden some properties
     RefreshableCredentials.__dict__['access_key'].fset: {
@@ -326,7 +331,9 @@ _API_DIGESTS = {
     },
     BotoProvider.load: {'e84ebfe3d6698dc4683f0f6699d4a9907c87bebb'},
     OriginalEC2Provider.load: {'dc58cd1c79d177105b183a2d20e1154e6f8f0733'},
-    create_credential_resolver: {'f3501ad2330afe5e1ef4e71c7537f94885c73821'},
+    create_credential_resolver: {
+        'fe797afd33126be87f86e44ab20475d50d727a4e',
+    },
     get_credentials: {'ff0c735a388ac8dd7fe300a32c1e36cdf33c0f56'},
     # configprovider.py
     SmartDefaultsConfigStoreFactory.merge_smart_defaults: {
@@ -421,7 +428,7 @@ _API_DIGESTS = {
     Session._register_response_parser_factory: {
         'bb8f7f3cc4d9ff9551f0875604747c4bb5030ff6'
     },
-    Session.create_client: {'8b1bd136aba5d0e519816aca7354b3d1e2dee7ec'},
+    Session.create_client: {'a821ae3870f33b65b1ea7cd347ca0497ed306ccd'},
     Session._create_token_resolver: {
         '142df7a219db0dd9c96fd81dc9e84a764a2fe5fb'
     },
@@ -440,22 +447,28 @@ _API_DIGESTS = {
     },
     # signers.py
     RequestSigner.handler: {'371909df136a0964ef7469a63d25149176c2b442'},
-    RequestSigner.sign: {'d90346d5e066e89cd902c5c936f59b644ecde275'},
+    RequestSigner.sign: {
+        '8b6ca96055e5546a6572ad790d5af74a23bc0b52',
+    },
     RequestSigner.get_auth: {'4f8099bef30f9a72fa3bcaa1bd3d22c4fbd224a8'},
     RequestSigner.get_auth_instance: {
-        '4f9be5feafd6c08ffd7bb8de3c9bc36bc02cbfc8'
+        'dcd41ea686506dcf056d8252ccf73acd501efd2b',
     },
     RequestSigner._choose_signer: {'bd0e9784029b8aa182b5aec73910d94cb67c36b0'},
     RequestSigner.generate_presigned_url: {
         '417682868eacc10bf4c65f3dfbdba7d20d9250db'
     },
     add_generate_presigned_url: {'5820f74ac46b004eb79e00eea1adc467bcf4defe'},
-    generate_presigned_url: {'48f6745f8a37cfba04b3b2f6fb3910210b4a7201'},
+    generate_presigned_url: {
+        'd03631d6810e2453b8874bc76619927b694a4207',
+    },
     S3PostPresigner.generate_presigned_post: {
         '269efc9af054a2fd2728d5b0a27db82c48053d7f'
     },
     add_generate_presigned_post: {'e30360f2bd893fabf47f5cdb04b0de420ccd414d'},
-    generate_presigned_post: {'eedf40b48c63f6772ed05e3f335c8193d187f503'},
+    generate_presigned_post: {
+        'a3a834a08be2cf76c20ea137ba6b28e7a12f58ed',
+    },
     add_generate_db_auth_token: {'f61014e6fac4b5c7ee7ac2d2bec15fb16fa9fbe5'},
     generate_db_auth_token: {'1f37e1e5982d8528841ce6b79f229b3e23a18959'},
     # tokens.py
@@ -488,16 +501,20 @@ _API_DIGESTS = {
         '2c7080f7d6ee5a3dacc1b690945c045dba1b1d21'
     },
     ContainerMetadataFetcher.retrieve_uri: {
-        '4ee8aa704cf0a378d68ef9a7b375a1aa8840b000'
+        '9067ffe122e6fcff4a7f4dd2b7f5b3de5e1ea4ec',
     },
     ContainerMetadataFetcher._retrieve_credentials: {
         'b00694931af86ef1a9305ad29328030ee366cea9'
     },
     ContainerMetadataFetcher._get_response: {
-        '4dc84054db957f2c1fb2fb1b01eb462bd57b1a64'
+        'b2c2fe2d74ce1894168e8e052c4e97cc70539b1a',
+    },
+    IMDSFetcher.__init__: {
+        '50ea982d3b94d7301d39480f827cfc1502800cb4',
+    },
+    IMDSFetcher._get_request: {
+        '118354ef768da5a7402d5d2bf6f55b4fbb2525e4',
     },
-    IMDSFetcher.__init__: {'e7e62b79f6a9e4cb14120e61c4516f0a61148100'},
-    IMDSFetcher._get_request: {'7f8ad4724ac08300a0c55e307bfeb5abc0579d26'},
     IMDSFetcher._fetch_metadata_token: {
         '12225b35a73130632038785a8c2e6fbaaf9de1f4'
     },
@@ -550,7 +567,19 @@ _API_DIGESTS = {
         '4631ced79cff143de5d3fdf03cd69720778f141b'
     },
     IMDSRegionProvider._create_fetcher: {
-        '7031d7cdaea0244a5d860f2f8f6c013e25578123'
+        '18da52c786a20d91615258a8127b566688ecbb39',
+    },
+    IdentityCache.get_credentials: {
+        'baf98c4caaddfa0594745eb490c327c65cff8920',
+    },
+    S3ExpressIdentityCache.get_credentials.__wrapped__: {
+        '71f2ae5e0ea32e9bbac6f318cba963700e23b9a0',
+    },
+    S3ExpressIdentityCache.build_refresh_callback: {
+        '0e833cc5e30b76fa13e8caf5c024fe2a21c10f22',
+    },
+    S3ExpressIdentityResolver.__init__: {
+        '148a10274d3268dd42df05d3bcfb98c668f01086',
     },
     # waiter.py
     NormalizedOperationMethod.__call__: {
@@ -567,7 +596,9 @@ _API_DIGESTS = {
         '86946722d10a72b593483fca0abf30100c609178'
     },
     # httpsession.py
-    URLLib3Session: {'c72094afb3aa62db0ade9be09be72ec7a2c3d80a'},
+    URLLib3Session: {
+        '1c418944abceb3a3d76c2c22348b4a39280d27ef',
+    },
     EndpointDiscoveryHandler.discover_endpoint: {
         'd87eff9008356a6aaa9b7078f23ba7a9ff0c7a60'
     },
@@ -615,7 +646,9 @@ _API_DIGESTS = {
     AWSResponse.content: {'307a4eb1d46360ef808a876d7d00cbbde6198eb1'},
     AWSResponse.text: {'a724100ba9f6d51b333b8fe470fac46376d5044a'},
     # httpchecksum.py
-    handle_checksum_body: {'4b9aeef18d816563624c66c57126d1ffa6fe1993'},
+    handle_checksum_body: {
+        '898cee7a7a5e5a02af7e0e65dcbb8122257b85df',
+    },
     _handle_bytes_response: {'0761c4590c6addbe8c674e40fca9f7dd375a184b'},
     AwsChunkedWrapper._make_chunk: {
         '097361692f0fd6c863a17dd695739629982ef7e4'
@@ -645,7 +678,7 @@ _API_DIGESTS = {
         '24b442126f0ff730be0ae64dc7158929d4d2fca7'
     },
     retryhandler.MaxAttemptsDecorator._should_retry: {
-        '8ba8bcec27974861ec35a7d91ce96db1c04833fe'
+        '581273f875bb779a9ff796df8c8597ec551abf97',
     },
     retryhandler.MultiChecker.__call__: {
         'e8302c52e1bbbb129b6f505633a4bc4ae1e5a34f'
@@ -656,6 +689,7 @@ _API_DIGESTS = {
     retryhandler.CRC32Checker._check_response: {
         '3ee7afd0bb1a3bf53934d77e44f619962c52b0c9'
     },
+    stub.Stubber: {'bccf23c3733cc656b909f5130cba80dbc9540b05'},
 }
 
 
@@ -672,15 +706,10 @@ def test_protocol_parsers():
 # NOTE: this doesn't require moto but needs to be marked to run with coverage
 @pytest.mark.moto
 def test_patches():
-    print(
-        "Botocore version: {} aiohttp version: {}".format(
-            botocore.__version__, aiohttp.__version__
-        )
-    )
+    print(f"Botocore version: {botocore.__version__}")
 
     success = True
-    for obj, digests in chain(_AIOHTTP_DIGESTS.items(), _API_DIGESTS.items()):
-
+    for obj, digests in _API_DIGESTS.items():
         try:
             source = getsource(obj)
         except TypeError:
